@@ -263,28 +263,6 @@ where
 // }
 
 
-#[derive(Debug)]
-pub enum ConvertError {
-    NotSupported(String, String),
-    FromAkitaError(AkitaData),
-}
-
-impl fmt::Display for ConvertError {
-    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        write!(
-            f,
-            "Couldn't convert the row `{:?}` to a desired type",
-            self.to_owned()
-        )
-    }
-}
-
-impl From<serde_json::Error> for ConvertError {
-    fn from(err: serde_json::Error) -> Self {
-        ConvertError::NotSupported(err.to_string(), "SerdeJson".to_string())
-    }
-}
-
 pub trait FromValue: Sized {
     fn from_value(v: &Value) -> Self {
         match Self::from_value_opt(v) {
